/**
 * Copyright (c) 2014 Leiden University Medical Center
 *
 * @author  Wibowo Arindrarto
 */

package nl.lumc.sasc.biopet.pipelines.gentrap.scripts

import java.io.File

import nl.lumc.sasc.biopet.core.config.Configurable
import nl.lumc.sasc.biopet.extensions.PythonCommandLineFunction
import org.broadinstitute.gatk.utils.commandline.{ Input, Output }

/**
 * Wrapper for the hist2count.py script, used internally in Gentrap
 */
class Hist2Count(val root: Configurable) extends PythonCommandLineFunction {

  setPythonScript("hist2count.py")

  @Input(doc = "Input histogram file (generated by bedtools coverage -hist)", required = true)
  var input: File = null

  @Output(doc = "Output count file", required = false)
  var outputGeneLevelCount: File = null

  /** index of column to copy to output file from input file */
  var copyColumn: List[Int] = List.empty[Int]

  def cmdLine = {
    getPythonCommand +
      required("-i", input) +
      required("-o", outputGeneLevelCount) +
      optional("-c", repeat(copyColumn), escape = false)
  }
}
